build_memory_context

Function build_memory_context 

pub fn build_memory_context(
    _workspace: &Path,
    agent_id: &str,
    user_message: &str,
) -> Option<String>
Build memory context by searching for relevant memories (BM25). Returns a context string to inject into the system prompt, or None if empty. Vector search for build_memory_context can be added later (requires async).