pub fn load_checkpoint(chat_root: &Path) -> Result<Option<RunCheckpoint>>Expand description
Load checkpoint from chat_root/run_checkpoints/latest.json. Returns None if no checkpoint exists or file is invalid.
pub fn load_checkpoint(chat_root: &Path) -> Result<Option<RunCheckpoint>>Load checkpoint from chat_root/run_checkpoints/latest.json. Returns None if no checkpoint exists or file is invalid.